<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Gweredekaat al lugant',
	'affichage' => 'Diskwel',
	'aide_non_disponible' => 'N’eo ket hegerz c’hoazh al lodenn-mañ eus ar skoazell enlinenn er yezh-mañ.',
	'annuler_recherche' => 'Nullañ an enklask',
	'auteur' => 'Skridaozer:',
	'avis_acces_interdit' => 'Digor difennet.',
	'avis_acces_interdit_prive' => 'N’ho peus ket an aotre da vont war ar bajenn-mañ<b>@exec@</b>.',
	'avis_article_modifie' => 'Diwallit, labouret ez eus bet war ar pennad-mañ gant @nom_auteur_modif@, @date_diff@ munutenn zo',
	'avis_aucun_resultat' => 'Disoc’h ebet.',
	'avis_base_inaccessible' => 'N’haller ket kevreañ ouzh an diaz roadennoù @base@.',
	'avis_chemin_invalide_1' => 'An hent dibabet ganeoc’h',
	'avis_chemin_invalide_2' => 'ne seblant ket bezañ reizh. Distroit d’ar bajenn a-raok ha gwiriit an titouroù pourchaset ganeoc’h.',
	'avis_connexion_echec_1' => 'C’hwitet eo ar c’hevreañ ouzh an diaz roadennoù.',
	'avis_connexion_echec_2' => 'Distroit d’ar bajenn a-raok, ha gwiriit an titouroù pourchaset ganeoc’h.',
	'avis_connexion_echec_3' => '<b>N.B.</b> War meur a servijer e tleit <b>goulenn</b> e vefe gweredekaet ho moned d’an diaz roadennoù a-raok gallout e implijout. Mar n’hallit ket kevreañ, gwiriit ha graet hoc’h eus ar goulenn-se.',
	'avis_connexion_erreur_creer_base' => 'N’eus ket bet gallet krouiñ an diaz roadennoù.',
	'avis_connexion_erreur_nom_base' => 'N’hall bezañ nemet lizherennoù, sifroù ha barrennigoù en anv an diaz',
	'avis_connexion_ldap_echec_1' => 'C’hwitet eo ar c’hevreañ ouzh ar servijer LDAP.',
	'avis_connexion_ldap_echec_2' => 'Distroit d’ar bajenn a-raok, ha gwiriit an titouroù pourchaset ganeoc’h.',
	'avis_connexion_ldap_echec_3' => 'A-hend-all n’implijit ket ar skor LDAP evit enporzhiañ implijerien.', # MODIF
	'avis_deplacement_rubrique' => 'Diwallit! Er rubrikenn-mañ ez eus @contient_breves@ berrskrid@scb@ : askit al logell-gadarnaat-mañ mard he dilec’hiit.',
	'avis_erreur_connexion_mysql' => 'Fazi kevreañ SQL',
	'avis_espace_interdit' => '<b>Lec’h difennet</b> <div>Staliet eo SPIP c’hoazh.</div>',
	'avis_lecture_noms_bases_1' => 'N’eo ket bet ar programm staliañ evit lenn anvioù an diazoù roadennoù staliet.',
	'avis_lecture_noms_bases_2' => 'Pe n’eus diaz hegerz ebet, pe diweredekaet eo bet al listennañ diazoù evit abegoù surentez (ar pezh a c’hoarvez gant meur a herberc’hier).',
	'avis_lecture_noms_bases_3' => 'A-hend-all e tlefec’h implijout un diaz dezhañ hoc’h anv kevreañ:',
	'avis_non_acces_page' => 'N’hoc’h eus ket moned d’ar bajenn-mañ.',
	'avis_operation_echec' => 'C’hwitet eo an ober.',
	'avis_operation_impossible' => 'Ober dibosupl',
	'avis_suppression_base' => 'DIWALLIT, hep distro eo lemel roadennoù',

	// B
	'bouton_acces_ldap' => 'Ouzhpennañ ar moned da LDAP',
	'bouton_ajouter' => 'Ouzhpennañ',
	'bouton_annuler' => 'Nullañ',
	'bouton_cache_activer' => ' Adweredekaat ar grubuilh',
	'bouton_cache_desactiver' => 'Diweredekaat ar grubuilh evit ur pennad',
	'bouton_demande_publication' => 'Goulenn ma vo embannet ar pennad-mañ',
	'bouton_desactive_tout' => 'Diweredekaat pep tra',
	'bouton_desinstaller' => 'Distaliañ',
	'bouton_effacer_tout' => 'Diverkañ PEP TRA',
	'bouton_envoyer_message' => 'Kemennadenn ziwezhañ: kas',
	'bouton_fermer' => 'Serriñ',
	'bouton_mettre_a_jour' => 'Hizivaat',
	'bouton_mettre_a_jour_base' => 'Hizivaat an diaz roadennoù',
	'bouton_modifier' => 'Kemmañ',
	'bouton_radio_afficher' => 'Diskwel',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Dont war-wel war roll ar skridaozerien kevreet', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Kas ar c’hemennoù d’ar chomlec’h-mañ:',
	'bouton_radio_envoi_liste_nouveautes' => 'Kas listenn an nevezentioù',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Na zont war-wel war roll ar skridaozerien kevreet', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Na gas kemennoù embann',
	'bouton_redirection' => 'ADHEÑCHAÑ',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Adderaouekaat an talvoudoù dre ziouer',
	'bouton_relancer_inscription' => 'Adlañsañ an enskrivadenn',
	'bouton_relancer_inscriptions' => 'Adlañsañ an enskrivadenn.',
	'bouton_relancer_installation' => 'Adlañsañ ar staliañ',
	'bouton_reset_password' => 'Krouiñ ur ger-tremen nevez hag e gas dre bostel',
	'bouton_suivant' => 'War-lerc’h',
	'bouton_tenter_recuperation' => 'Klask dresañ',
	'bouton_test_proxy' => 'Esaeañ ar proksi',
	'bouton_vider_cache' => 'Goullonderiñ ar grubuilh',

	// C
	'cache_modifiable_webmestre' => 'Kemmet e c’hall bezañ an arventenn-mañ gant mestr-gwiad al lec’hienn.', # MODIF
	'calendrier_synchro' => 'Mard implijit ur meziant deiziataer kenglotus gant <b>iCal</b> e c’hallit e gembredañ gant titouroù al lec’hienn-mañ.',
	'config_activer_champs' => 'Gweredekaat ar maeziennoù-mañ',
	'config_choix_base_sup' => 'merkañ un diaz war ar servijer-mañ',
	'config_erreur_base_sup' => 'N’en deus ket SPIP moned da roll an diazoù digor',
	'config_info_base_sup' => 'Mard hoc’h eus diazoù roadennoù all da c’houlennata dre SPIP, gant e servijer SQL pe gant unan bennak all, e c’hallit o disklêriañ gant ar furmskrid-mañ dindan. Mar ne skrivit netra e maeziennoù zo e vo implijet an anaouderioù kevreañ ouzh an diaz pennañ.',
	'config_info_base_sup_disponibles' => 'Diazoù ouzhpenn a c’haller goulennata c’hoazh:',
	'config_info_enregistree' => 'Enrollet eo bet ar c’hefluniadur nevez',
	'config_info_logos' => 'Pep a logo, ha pep a “logo nijal a-us” a c’hall bezañ lakaet da elfennoù al lec’hienn.',
	'config_info_logos_utiliser' => 'Implijout al logoioù',
	'config_info_logos_utiliser_non' => 'Na implijout al logoioù',
	'config_info_logos_utiliser_survol' => 'Implijout al logoioù nijal a-us',
	'config_info_logos_utiliser_survol_non' => 'Na implijout al logoioù nijal a-us',
	'config_info_redirection' => 'Pa vo gweredekaet an dibab-mañ e c’hallot krouiñ pennadoù galloudel, ha na vint nemet daveoù da bennadoù bet embannet e lec’hiennoù all, pe er-maez eus SPIP.',
	'config_redirection' => 'Pennadoù galloudel',
	'config_titre_base_sup' => 'Disklêriañ un diaz ouzhpenn',
	'config_titre_base_sup_choix' => 'Dibabit un diaz ouzhpenn',
	'connexion_ldap' => 'Kevreañ:',
	'creer_et_associer_un_auteur' => 'Krouiñ ha kevrediñ un aozer',

	// D
	'date_mot_heures' => 'eur',

	// E
	'ecran_connexion_couleur_principale' => 'Liv kentañ penn',
	'ecran_connexion_image_fond' => 'Skeudenn adreñv',
	'ecran_connexion_image_fond_explication' => 'Ober gant ur skeudenn (stumm JPEG, 1920x1080 pixels)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Distreiñ d’al liv dre ziouer',
	'ecran_connexion_titre' => 'Skramm evit kennaskañ',
	'ecran_securite' => ' + skramm surentez @version@',
	'email' => 'postel',
	'email_2' => 'postel:',
	'en_savoir_plus' => 'Gouzout muioc’h',
	'entree_adresse_annuaire' => 'Chomlec’h eus al levr',
	'entree_adresse_email' => 'Ho postel',
	'entree_adresse_email_2' => ' Chomlec’h postel ',
	'entree_base_donnee_1' => 'Chomlec’h an diaz roadennoù',
	'entree_base_donnee_2' => '(Alies e klot ar chomlec’h-se gant hini ho lec’hienn, a-wezhioù e klot gant ar meneg «localhost», a-wezhioù e chom goullo-krenn.)',
	'entree_biographie' => 'Buhezskrid berr-ha-berr.',
	'entree_chemin_acces' => '<b>Skrivañ</b> an hent moned:',
	'entree_cle_pgp' => 'Hoc’h alc’hwez PGP',
	'entree_cle_pgp_2' => 'Alc’hwez PGP',
	'entree_contenu_rubrique' => '(Endalc’h ar rubrikenn berr-ha-berr)',
	'entree_identifiants_connexion' => 'Hoc’h anaouderioù kevreañ...',
	'entree_identifiants_connexion_2' => 'Anaouderioù kevreañ',
	'entree_informations_connexion_ldap' => 'Skrivit er furmskrid-mañ titouroù kevreañ ho levr chomlec’h LDAP.
 Merour ho reizhiad pe ho rouedad a zlefe gallout o fourchas deoc’h.', # MODIF
	'entree_infos_perso' => 'Piv oc’h-c’hwi?',
	'entree_infos_perso_2' => 'Piv eo an aozer?',
	'entree_interieur_rubrique' => 'Er rubrikenn:',
	'entree_liens_sites' => '<b>Gourliamm</b> (daveenn, lec’hienn da weladenniñ...)',
	'entree_login' => 'Ho ker kevreañ',
	'entree_login_connexion_1' => 'Ar ger kevreañ',
	'entree_login_connexion_2' => '(A-wezhioù e klot gant ho ker moned da FTP, a-wezhioù emañ da vezañ lezet goullo)',
	'entree_mot_passe' => 'Ho ker-tremen',
	'entree_mot_passe_1' => 'Ar ger-tremen kevreañ',
	'entree_mot_passe_2' => '(A-wezhioù e klot gant ar ger-tremen da FTP, a-wezhioù emañ da vezañ lezet goullo)',
	'entree_nom_fichier' => 'Skrivit anv ar restr @texte_compresse@:',
	'entree_nom_pseudo' => 'Hoc’h anv pe ho lesanv',
	'entree_nom_pseudo_1' => '(Hoc’h anv pe ho lesanv)',
	'entree_nom_pseudo_2' => 'Anv pe lesanv',
	'entree_nom_site' => 'Anv ho lec’hienn',
	'entree_nom_site_2' => 'Anv lec’hienn an aozer',
	'entree_nouveau_passe' => 'Ger-tremen nevez',
	'entree_passe_ldap' => 'Ger-tremen',
	'entree_port_annuaire' => 'Niverenn borzh al levr chomlec’h',
	'entree_signature' => 'Sinadur',
	'entree_titre_obligatoire' => '<b>Titl</b> [Ret]<br />',
	'entree_url' => 'Chomlec’h (URL) ho lec’hienn',
	'entree_url_2' => 'Chomlec’h (URL) al lec’hienn',
	'erreur_connect_deja_existant' => 'Un dafariad zo c’hoazh gant an anv-se.',
	'erreur_contenu_suspect' => 'Testenn tec’het',
	'erreur_email_deja_existant' => 'Enrollet eo bet c’hoazh ar postel-se.',
	'erreur_nom_connect_incorrect' => 'N’eo ket aotreet an anv dafariad-se ',
	'erreur_plugin_attribut_balise_manquant' => 'Doareenn @attribut@ a vank er valizenn @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'C’hwitet eo da zistaliañ al lugant. E ziweredekaat a c’hallit avat.',
	'erreur_plugin_fichier_absent' => 'Restr ezvezant',
	'erreur_plugin_fichier_def_absent' => 'Restr termenañ ezvezant',
	'erreur_plugin_nom_fonction_interdit' => 'Anv arc’hwel difennet',
	'erreur_plugin_nom_manquant' => 'Anv lugant ezvezant',
	'erreur_plugin_prefix_manquant' => 'N’eo ket termenet tachenn envel al lugant',
	'erreur_plugin_tag_plugin_absent' => '&lt;lugant&gt; ezvezant er restr termenañ',
	'erreur_plugin_version_manquant' => 'Stumm al lugant ezvezant',
	'erreur_type_fichier' => 'Stumm restr fall',

	// H
	'htaccess_a_simuler' => 'Diwall: Ne vez ket dalc’het kont eus ar restroù @htaccess@ gant ho tafariad HTTP. Evit diogeliñ surentez vat eo ret deoc’h kemmañ ar c’hefluniadur-mañ war ar c’hraf-mañ, peotramant eo ret o defe an digemmennoù @constantes@ (a c’haller termenañ er restr  mes_options.php) talvoudoù levrioù-chomlec’h er-maez eus @document_root@.',
	'htaccess_inoperant' => 'htaccess ne ra netra',

	// I
	'ical_info1' => 'War ar bajenn-mañ ez eus meur a hentenn evit chom e darempred gant buhez al lec’hienn-mañ.',
	'ical_info2' => 'Evit gouzout hiroc’h diwar-benn an teknikoù-se, klaskit hardizh e-barzh <a href="@spipnet@">teuliadur SPIP</a>.',
	'ical_info_calendrier' => 'Daou zeiziadur zo en ho kerz. An hini kentañ zo ur plaen eus al lec’hienn hag a ziskouez an holl bennadoù bet embannet. An eil emañ warnañ ar c’hemennoù stur, koulz hag ho kemennadennoù prevez diwezhañ: miret eo evidoc’h dre berzh un alc’hwez personel, a c’hallit kemm n’eus forzh pegoulz pa nevezot ho ker-tremen.',
	'ical_methode_http' => 'Pellgargañ',
	'ical_methode_webcal' => 'Kempredañ (webcal://)',
	'ical_texte_prive' => 'An deiziataer hiniennel-mañ a gelaou ac’hanoc’h diwar-benn nevezinti embann prevez al lec’hienn-mañ (labourioù, emgavioù, pennadoù, berrskridoù kinniget,...).',
	'ical_texte_public' => 'Gant an deiziataer-mañ e c’hellit heuliañ nevezenti foran al lec’hienn (pennadoù ha berrskridoù bet embannet).',
	'ical_texte_rss' => 'Gallout a rit sindikadiñ nevezenti ar forom-mañ war forzh peseurt lenner restroù XML/RSS (Rich Site Summary). A-drugarez d’ar furmad-se ivez e c’hell SPIP lenn an nevezenti war al lec’hiennoù all hag a implij ur stumm kenlotus(lec’hiennoù sindikadet).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Roll-skignañ',
	'ical_titre_rss' => 'Restroù sindikadañ',
	'icone_accueil' => 'Degemer',
	'icone_activer_cookie' => 'Gweredekaat an toupin heuliañ',
	'icone_activite' => 'Gwerederezh',
	'icone_admin_plugin' => 'Merañ an adveziantoù',
	'icone_administration' => 'Trezalc’h',
	'icone_afficher_auteurs' => 'Diskouez ar skridaozerien',
	'icone_afficher_visiteurs' => 'Diskouez ar weladennerien',
	'icone_arret_discussion' => 'Paouez da gemer perzh er gaoz-mañ',
	'icone_calendrier' => 'Deiziataer',
	'icone_configuration' => 'Kefluniad',
	'icone_creer_auteur' => 'Krouiñ ur skridaozer nevez, hag e stagañ ouzh ar pennad-mañ',
	'icone_creer_mot_cle' => 'Krouiñ ur ger-stur nevez hag e liammañ ouzh ar pennad-mañ',
	'icone_creer_rubrique_2' => 'Krouiñ ur rubrikenn nevez',
	'icone_developpement' => 'Diorenniñ',
	'icone_edition' => 'Embannadur',
	'icone_ma_langue' => 'Va yezh',
	'icone_mes_infos' => 'Va stlennadoù',
	'icone_mes_preferences' => 'Va dibaboù',
	'icone_modifier_article' => 'Kemmañ ar pennad-mañ',
	'icone_modifier_rubrique' => 'Kemmañ ar rubrikenn-mañ',
	'icone_publication' => 'Embann',
	'icone_relancer_signataire' => 'Adlañsañ ar siner',
	'icone_retour' => 'Distro',
	'icone_retour_article' => 'Distreiñ d’ar pennad',
	'icone_squelette' => 'Frammoù',
	'icone_suivi_publication' => 'Heuliañ an embann',
	'icone_supprimer_cookie' => 'Diverkañ an toupin heuliañ',
	'icone_supprimer_rubrique' => 'Diverkañ ar rummad-mañ',
	'icone_supprimer_signature' => 'Diverkañ ar sinadur-mañ',
	'icone_valider_signature' => 'Aprouiñ ar sinadur-mañ',
	'image_administrer_rubrique' => 'Gallout a rit merañ ar rubrikenn-mañ',
	'impossible_modifier_login_auteur' => ' Login digemm',
	'impossible_modifier_pass_auteur' => 'Ger-tremen digemm.',
	'info_1_article' => '1 pennad',
	'info_1_auteur' => '1 aozer',
	'info_1_message' => '1 kemennad',
	'info_1_mot_cle' => '1 ger-alc’hwez',
	'info_1_rubrique' => '1 rubrikenn',
	'info_1_visiteur' => '1 gweladenner',
	'info_activer_cookie' => 'Gallout a rit implijout un <b>toupin heuliañ</b>, ar pezh a dalvezo deoc’h da dremen en un doare aes eus al lec’hienn brevez d’an hini foran.',
	'info_activer_menu_developpement' => 'Diskouez al roll Diorrenniñ',
	'info_admin_etre_webmestre' => 'Reiñ din gwirioù ur mestr-gwiad ',
	'info_admin_je_suis_webmestre' => 'mestr-gwiad <b>ez on</b>',
	'info_admin_statuer_webmestre' => 'Reiñ gwirioù ur mestr-gwiad d’an amaezhier-mañ', # MODIF
	'info_admin_webmestre' => 'An amaezhier-mañ zo<b>mestr-gwiad</b>', # MODIF
	'info_administrateur' => 'Merour', # MODIF
	'info_administrateur_1' => 'Merour', # MODIF
	'info_administrateur_2' => 'al lec’hienn (<i>diwallit en ur implijout se</i>)',
	'info_administrateur_site_01' => 'Ma’z oc’h merour al lec’hienn,', # MODIF
	'info_administrateur_site_02' => 'klikit war al liamm-mañ',
	'info_administrateurs' => 'Merourien', # MODIF
	'info_administrer_rubrique' => 'Gallout a rit merañ ar rubrikenn-mañ',
	'info_adresse' => 'er chomlec’h :',
	'info_adresse_desinscription' => 'Postel evit en em zisenskrivañ : ',
	'info_adresse_url' => 'Chomlec’h (URL) al lec’hienn foran',
	'info_afficher_par_nb' => 'Diskouez dre',
	'info_aide_en_ligne' => 'Skoazell enlinenn SPIP',
	'info_ajout_image' => 'Pa ouzhpennit skeudennoù evel restroù stag ouzh ur pennad 
  e c’hell SPIP krouiñ ent emgefre evidoc’h skeudennoùigoù (bihanaet) eus
ar skeudennoù enframmet. Evel-se e c’heller krouiñ, da skouer,
  ur skeudennaoueg pe ur portofolio.',
	'info_ajouter_rubrique' => 'Ouzhpennañ ur rubrikenn all da vezañ meret :',
	'info_annonce_nouveautes' => 'Kemenn an nevezenti',
	'info_article' => 'pennad',
	'info_article_2' => 'pennad',
	'info_article_a_paraitre' => 'Ar pennadoù goude-deiziataet da zont',
	'info_articles_02' => 'pennad',
	'info_articles_2' => 'Pennad',
	'info_articles_auteur' => 'Pennadoù ar skridaozer-mañ',
	'info_articles_miens' => 'Va fennadoù-skrid',
	'info_articles_tous' => 'An holl bennadoù-skrid',
	'info_articles_trouves' => 'Pennadoù kavet',
	'info_attente_validation' => 'Ho pennadoù a chom da vezañ aprouet',
	'info_aucun_article' => 'Pennad-skrid ebet',
	'info_aucun_auteur' => 'Aozer ebet',
	'info_aucun_message' => 'kemennad ebet',
	'info_aucun_rubrique' => 'Rubrikenn ebet',
	'info_aujourdhui' => 'hiziv :',
	'info_auteur_gere_rubriques' => 'Ar skrivagner-mañ a ver ar rubrikennoù a-heul :',
	'info_auteur_gere_toutes_rubriques' => 'Ar skrivagner-mañ a ra war-dro <b>an holl rubrikennoù</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Merañ a ran <b>pep rubrikenn</b>',
	'info_auteurs' => 'Ar skridaozerien',
	'info_auteurs_par_tri' => 'Skridaozerien@partri@',
	'info_auteurs_trouves' => 'Skridaozerien kavet',
	'info_authentification_externe' => 'Gwiriekadur diavaez',
	'info_avertissement' => 'Kemenn diwall',
	'info_barre_outils' => 'gant e varrenn ostilhoù ?',
	'info_base_installee' => 'Staliet eo framm ho tiaz-titouroù.',
	'info_bio' => 'Buhezskrid',
	'info_cache_desactive' => 'Diwerekaet eo bet ar grubuilh evit ur pennad.',
	'info_chapeau' => 'Tog',
	'info_chapeau_2' => 'Tog :',
	'info_chemin_acces_1' => 'Dibarzhioù : <b>hent moned er rollad tud</b>',
	'info_chemin_acces_2' => 'Bremañ e rankit kefluniañ anhent moned a-benn tizhout titouroù ar rollad tud. Ezhomm zo eus an titour-se evit gallout lenn profiloù an implijerien a gaver er rollad tud.', # MODIF
	'info_chemin_acces_annuaire' => 'Dibarzhioù : <b>Hent moned er rollad tud</b>',
	'info_choix_base' => 'Trede lankad :',
	'info_classement_1' => '<sup>añ</sup> war @liste@',
	'info_classement_2' => '<sup>vet</sup> war @liste@',
	'info_code_acces' => 'N’ankouait ket ho kodoù moned !',
	'info_config_suivi' => 'Ma’z eo ar chomlec’h-mañ hini ur roll-skignañ e c’hellit skrivañ amañ ar chomlec’h evit en em enrollañ. Gallout a ra ar chomlec’h-se bezañ un URL (hini ar bajenn Web m’en em enroller warni), pe ur postel diwar-benn un danvez bennak (da skouer : <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Gallout a rit en em enrollañ war roll-skignañ al lec’hienn-mañ. Degaset e vo deoc’h kemennoù dre bostel pa vo kinniget pennadoù pe berrskridoù nevez neuze.',
	'info_confirmer_passe' => 'Gwiriañ ar ger-tremen :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Diwallit, kemmet eo bet an maeziennoù-mañ e lec’h all. Setu ma n’eo ket bet enrollet ho kemmoù warno.',
	'info_conflit_edition_differences' => 'Diforc’hioù :',
	'info_conflit_edition_version_enregistree' => 'Ar stumm bet enrollet :',
	'info_conflit_edition_votre_version' => 'Ho stumm :',
	'info_connexion_base' => 'O klask kevreañ ouzh an diaz titouroù',
	'info_connexion_base_donnee' => 'Kevreañ ouzh ho tiaz titouroù',
	'info_connexion_ldap_ok' => 'Kevreet oc’h dre LDAP.</b><p>Gallout a rit tremen d’al lankad war-lerc’h.</p>',
	'info_connexion_mysql' => 'Ho kevreadenn SQL',
	'info_connexion_ok' => 'Kevreet oc’h.',
	'info_contact' => 'Darempred',
	'info_contenu_articles' => 'Danvez ar pennadoù',
	'info_contributions' => 'Degasadennoù',
	'info_creation_paragraphe' => '(Evit krouiñ rannbennadoù, lezit goullo linennoù zo traken)',
	'info_creation_rubrique' => 'A-benn gallout skrivañ pennadoù <br />e rankit bezañ krouet ur rubrikenn da nebeutañ.<br />',
	'info_creation_tables' => 'Krouiñ taolennoù an diaz titouroù',
	'info_creer_base' => '<b>Krouiñ</b> un diaz titouroù nevez :',
	'info_dans_rubrique' => 'Er rubrikenn :',
	'info_date_publication_anterieure' => 'Deiziad skridaozañ kent :',
	'info_date_referencement' => 'DEIZIAD MENEGERIÑ AL LEC’HIENN-MAÑ :',
	'info_derniere_etape' => 'Echuet eo !',
	'info_descriptif' => 'Deskrivadur :',
	'info_desinstaller_plugin' => 'diverkañ a ra ar roadoù, ha diweredekaat a ra an adveziant',
	'info_discussion_cours' => 'Kaozeadennoù digor',
	'info_ecrire_article' => 'A-benn gallout skrivañ pennadoù e rankit bezañ krouet ur rubrikenn da nebeutañ.',
	'info_email_envoi' => 'Postel kas (diret)',
	'info_email_envoi_txt' => 'Skrivit amañ chomlec’h kas ar postelioù (ma ne skrivit netra e vo implijet chomlec’h an degemererien) :',
	'info_email_webmestre' => 'Postel ar webmestr (diret)', # MODIF
	'info_envoi_email_automatique' => 'Kas postelioù emgefre',
	'info_envoyer_maintenant' => 'Kas bremañ',
	'info_etape_suivante' => 'Tremen d’al lankad war-lerc’h',
	'info_etape_suivante_1' => 'Gallout a rit tremen d’al lankad war-lerc’h.',
	'info_etape_suivante_2' => 'Gallout a rit tremen d’ar lankad war-lerc’h.',
	'info_exceptions_proxy' => 'Nemedennoù evit ar proxy',
	'info_exportation_base' => 'Oc’h ezporzhiañ an diaz davet @archive@',
	'info_facilite_suivi_activite' => 'A-benn heuliañ aesoc’h an oberererezh e c’hell SPIP kas dre bostel,
  d’ul roll-skignañ enni ar skridaozerien da skouer,
  ar goulennoù embann ha kadarnaat ar pennadoù.', # MODIF
	'info_fichiers_authent' => 'Restroù gwiriekaat « .htpasswd »',
	'info_forums_abo_invites' => 'Foromoù dre goumanant zo war ho lec’hienn ; pedet e vez ar weladennerien d’en em enrollañ war lodenn foran al lec’hienn neuze.', # MODIF
	'info_gauche_admin_tech' => '<b>N’eus nemet an dud e-karg eus al lec’hienn a c’hall mont war ar bajenn-mañ.</b><p> Warni e reer al labourioù kempenn. Evit traoù zo ez eus ezhomm eus un argerzh testeniekaat dibar a c’houlenn kaout ur moned FTP ouzh al lec’hienn.</p>',
	'info_gauche_auteurs' => 'Amañ e kavot an holl dud a skriv war al lec’hienn.
 Diouzh liv o skeudennig e c’hellit gouzout o c’harg resis (merour=gwer; skridaozer=melen).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'E glaz emañ diskouezet ar skridaozerien diavaez, hep moned ouzh al lec’hienn ;
  Gant ur pod-lastez eo aroueziet ar re bet diverket.',
	'info_gauche_messagerie' => 'Dre ar postelerezh e c’hellit eskemm kemennadennoù gant skridaozerien all, derc’hel notennigoù-eñvor, pe, ma’z oc’h merour, skignañ kemennoù war bajenn degemer al lodenn brevez.', # MODIF
	'info_gauche_statistiques_referers' => 'War ar bajenn-mañ emañ roll ar <i>referers</i>, da lavaret eo al lec’hiennoù enno liammoù a gas davet ho lec’hienn deoc’h, evit dec’h hag hiziv hepken. Riñset e vez ar roll-mañ bemdez.',
	'info_gauche_visiteurs_enregistres' => 'Amañ emañ ar weladennerien enrollet evit gallout kemer perzh e foromoù dre goumanant lodenn foran al lec’hienn.',
	'info_generation_miniatures_images' => 'Krouiñ skeudennoùigoù',
	'info_gerer_trad_objets' => '@objets@ : merañ liammoù an troidigezh',
	'info_hebergeur_desactiver_envoi_email' => 'Herberc’herien zo a nac’h ma vefe kaset postelioù emgedre adal o servijerioù. En deoguezh-se, ne’z aio ket ar servijoù-se en-dro.',
	'info_hier' => 'dec’h :',
	'info_identification_publique' => 'Hoc’h anv foran...',
	'info_image_process' => 'Diuzit an hentenn wellañ da sevel skeudennoùigoù o klikañ war ar skeudenn a zere.',
	'info_image_process2' => '<b>Evezh.</b> <i>Ma ne weler skeudenn ebet e talvez n’eo ket bet kefluniet an dafariad a ro bod deoc’h evit ober gant seurt binvioù. Mar fell deoc’h implijout ar servijoù-se, kit e darempred gant an dud e-karg, ha goulennit war-lerc’h an astennoù «GD» pe «Imagick».</i>',
	'info_images_auto' => 'Skeudennoù jedet ent emgefre',
	'info_informations_personnelles' => 'Titouroù personel',
	'info_inscription' => 'enskrivadur el linenn',
	'info_inscription_automatique' => 'Enskrivadur emgefreek ar skridaozerien nevez.', # MODIF
	'info_jeu_caractere' => 'Strobad arouezennoù al lec’hienn',
	'info_jours' => 'deiz',
	'info_laisser_champs_vides' => '(lezit ar maeziennoù-mañ goullo)',
	'info_langues' => 'Yezhoù al lec’hienn',
	'info_ldap_ok' => 'Staliet eo ar gwiriekaat LDAP.',
	'info_lien_hypertexte' => 'Liamm gourskrid :',
	'info_liste_nouveautes_envoyee' => 'Kaset eo bet roll an nevezentioù',
	'info_liste_redacteurs_connectes' => 'Roll ar skridaozerien kevreet', # MODIF
	'info_login_existant' => 'C’hoazh ez eus eus ar ger kevreañ-mañ.',
	'info_login_trop_court' => 'Re verr eo ar ger-kevreañ.',
	'info_login_trop_court_car_pluriel' => 'Ret eo lakaat@nb@ arouezenn da vihanañ.',
	'info_logos' => 'Al logoioù',
	'info_maximum' => 'd’ar muiañ :',
	'info_meme_rubrique' => 'En hevelep rubrikenn',
	'info_message_en_redaction' => 'Ar c’hemennadennoù emaoc’h o skrivañ',
	'info_message_technique' => 'Kemennadenn deknikel :',
	'info_messagerie_interne' => 'Postelerezh diabarzh',
	'info_mise_a_niveau_base' => 'lakaat ho tiaz titouroù SQL a-live',
	'info_mise_a_niveau_base_2' => '{{Diwallit!}} Staliet ho peus ur stumm eus SPIP {koshoc’h} eget an hini a oa war al lec’hienn-mañ a-raok .
Riskloù zo e vefe distrujet ho tiaz titouroù pe ne’z afe ket en-dro ken.<br />{{Adstailhit restroù SPIP.}}',
	'info_modification_enregistree' => 'lerc’hwezet eo bet ho taskemm',
	'info_modifier_auteur' => 'Kemmañ an aozer :',
	'info_modifier_rubrique' => 'Kemmañ ar rubrikenn :',
	'info_modifier_titre' => 'Kemmañ : @titre@',
	'info_mon_site_spip' => 'Ma lec’hienn SPIP',
	'info_moyenne' => 'Keidenn :',
	'info_multi_cet_article' => 'Yezh ar pennad-mañ :',
	'info_multi_langues_choisies' => 'Dibabit amañ dindan ar yezhoù a c’hell skridaozerien ho lec’hienn skrivañ enno.
  Ar yezhoù bet implijet betek-henn (diskouezet da gentañ) n’hallont ket bezañ lamet kuit.', # MODIF
	'info_multi_objets' => '@objets@ : gweredekaat lañser ar yezh',
	'info_multi_secteurs' => '...evit rubrikennoù ar wrizienn hepken ?',
	'info_nb_articles' => '@nb@ pennadoù-skrid',
	'info_nb_auteurs' => '@nb@ aozerion',
	'info_nb_messages' => '@nb@ kemennadoù',
	'info_nb_mots_cles' => '@nb@ gerioù-alc’hwez',
	'info_nb_rubriques' => '@nb@ rubrikennoù',
	'info_nb_visiteurs' => '@nb@ gweladennerion',
	'info_nom' => 'Anv',
	'info_nom_destinataire' => 'Anv an degemerer',
	'info_nom_pas_conforme' => 'n’eo ket aotreet an tagoù html ',
	'info_nom_site' => 'Anv ho lec’hienn',
	'info_nombre_articles' => '@nb_articles@ pennad,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubrikenn,',
	'info_nombre_sites' => '@nb_sites@ lec’hienn,',
	'info_non_deplacer' => 'Na zilec’hiañ...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'Gallout a ra SPIP kelaouiñ en un doare reoliek war nevezenti al lec’hienn
  (pennadoù ha berrskridoù embannet nevez zo).',
	'info_non_envoi_liste_nouveautes' => 'Chom hep kas roll an nevezenti',
	'info_non_modifiable' => 'n’hall ket bezañ kemmet',
	'info_non_suppression_mot_cle' => 'ne fell ket din diverkañ ar ger-stur-mañ.',
	'info_notes' => 'Notennoù',
	'info_nouvel_article' => 'Pennad nevez',
	'info_nouvelle_traduction' => 'Troidigezh nevez :',
	'info_numero_article' => 'PENNAD NIVERENN :',
	'info_obligatoire_02' => '[Rekis]',
	'info_option_accepter_visiteurs' => 'Aotren enrolladennoù gweladennerien al lec’hienn foran', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Nac’hañ enrolladennoù ar weladennerien', # MODIF
	'info_options_avancees' => 'DIBARZHIOÙ PISHOC’H',
	'info_ou' => 'pe...',
	'info_page_interdite' => 'Pajenn difennet',
	'info_par_nom' => 'dre anv',
	'info_par_nombre_article' => 'dre an niver a bennadoù',
	'info_par_statut' => 'dre statud',
	'info_par_tri' => '’(dre @tri@)’',
	'info_passe_trop_court' => 'Ger-tremen re verr.',
	'info_passe_trop_court_car_pluriel' => 'Lakait d’’ar vihanañ @nb@ arouezenn er ger-tremen.',
	'info_passes_identiques' => 'Ne glot ket an daou c’her-tremen.',
	'info_plus_cinq_car' => 'ouzhpenn pemp arouezenn',
	'info_plus_cinq_car_2' => '(Ouzhpenn 5 arouezenn)',
	'info_plus_trois_car' => '(Ouzhpenn 3 arouezenn)',
	'info_popularite' => 'brud; : @popularite@ ; gweladennoù : @visites@',
	'info_post_scriptum' => 'Goude-skrid',
	'info_post_scriptum_2' => 'Goude-skrid :',
	'info_pour' => 'evit',
	'info_preview_texte' => 'Posupl eo rakwelet  holl bennadoù al lec’h gant ar statud « kinniget » d’an nebeutañ, hag an holl verrskridoù a vezer an oberour anezho. Daoust ha dleout a rafe an holl verourien gallout en ober, pe ar skridaozerien, pe den ebet ?', # MODIF
	'info_procedez_par_etape' => 'kit war-raok pazenn-ha-pazenn',
	'info_procedure_maj_version' => 'rankout a ra al labour hizivaat bezañ lañset a-benn azasaat 
 an diaz titouroù ouzh stumm nevez SPIP.',
	'info_proxy_ok' => 'Mat eo bet disoc’h arnod ar proksi.',
	'info_ps' => 'G.S.',
	'info_publier' => 'embann',
	'info_publies' => 'Ho pennadoù bet embannet',
	'info_question_accepter_visiteurs' => 'M’eo resisaet e frammoù ho lec’hienn e c’hall ar weladennerien en em enrollañ hep moned ouzh al lodenn brevez, gweredekait an dibarzh a-is :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Hag aotren a rit e c’hallfe skridaozerien nevez en em enrollañ adalek al lec’hienn foran ?
  Ma asantit e c’hallo ar weladennerien en em enskrivañ adalek ur furmskrid emgefreek, 
  ha gouest e vint neuze da dizhout al lodenn brevez evit kinnig o fennadoù dezho o-unan.
  <blockquote><i>Da vare an enrollañ e vez kaset ur postel emgefreek d’ar skridaozerien
  ennañ ar c’hodoù da c’hallout dont tre el lec’hienn.
  Gant herberc’herien zo e vez difennet kas postelioù adalek o servijerioù,
  en degouezh-se ne vo ket tu en em enrollañ ent emgefre.</i></blockquote>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ en deus labouret war an danvez-se @date_diff@ minutes zo',
	'info_racine_site' => 'Gwrizienn al lec’hienn',
	'info_recharger_page' => 'Adkargit ar-bajenn-mañ a-raok pell, mar plij.',
	'info_recherche_auteur_zero' => 'N’eus bet kavet disoc’h ebet evit « @cherche_auteur@ ».',
	'info_recommencer' => 'Klaskit en-dro mar plij.',
	'info_redacteur_1' => 'Skridaozer',
	'info_redacteur_2' => 'aotreet da vont war al lodenn brevez (<i>erbedet</i>)',
	'info_redacteurs' => 'Skridaozerien',
	'info_redaction_en_cours' => 'O VEZAÑ SKRIDAOZET',
	'info_redirection' => 'Adheñchañ',
	'info_redirection_activee' => 'War adwerediñ',
	'info_redirection_boucle' => 'Emaoc’h o klask adkas ur pennad-skrid warnañ e-unan.',
	'info_redirection_desactivee' => 'Torret eo bet an adwerediñ.',
	'info_refuses' => 'Ho pennadoù bet nac’het',
	'info_reglage_ldap' => 'Dibarzhioù : <b>Reizhañ an enporzhiañ LDAP</b>',
	'info_renvoi_article' => '<b>Adheñchañ.</b> Adkas a ra ar pennad-mañ d’ar bajenn :',
	'info_reserve_admin' => 'N’eus nemet ar verourien a c’hall kemmañ ar chomlec’h-mañ.', # MODIF
	'info_restreindre_rubrique' => 'Strishaat ar merañ d’ar rubrikenn-mañ :',
	'info_resultat_recherche' => 'Disoc’hoù an enklask :',
	'info_rubriques' => 'Rubrikennoù',
	'info_rubriques_02' => 'rubrikennoù',
	'info_rubriques_trouvees' => 'Rubrikennoù bet kavet',
	'info_sans_titre' => 'Titl ebet',
	'info_selection_chemin_acces' => '<b>Diuzit</b> amañ dindan an hent evit tizhout ar rollad tud :',
	'info_signatures' => 'sinadurioù',
	'info_site' => 'Lec’hienn',
	'info_site_2' => 'lec’hienn :',
	'info_site_min' => 'lec’hienn',
	'info_site_reference_2' => 'Lec’hienn menegeret',
	'info_site_web' => 'Load internet :',
	'info_sites' => 'lec’hiennoù',
	'info_sites_lies_mot' => 'Al lec’hiennoù menegeret liammet ouzh ar ger-stur-mañ',
	'info_sites_proxy' => 'Implijout ur proksi',
	'info_sites_trouves' => 'Lec’hiennoù bet kavet',
	'info_sous_titre' => 'Istitl :',
	'info_statut_administrateur' => 'Merour', # MODIF
	'info_statut_auteur' => 'Statud ar skridaozer-mañ :',
	'info_statut_auteur_2' => 'Me a zo',
	'info_statut_auteur_a_confirmer' => 'Enskrivadur da gadarnaat',
	'info_statut_auteur_autre' => 'Statud all :',
	'info_statut_redacteur' => 'Skridaozer',
	'info_statut_utilisateurs_1' => 'Staelad dre ziouer an implijerion enporzhiet', # MODIF
	'info_statut_utilisateurs_2' => 'Dibabit ar statud da reiñ da dud ar rollad tud LDAP pa gevreont evit ar wech kentañ. Gallout a reoo da c’houde kemmañ ar statud-se unan evit pep aozer unan hag unan.', # MODIF
	'info_suivi_activite' => 'Heuliañ an embannerezh',
	'info_surtitre' => 'Ustitl :',
	'info_syndication_integrale_1' => 'Kinnig a ra ho lec’hienn restroù sindikadañ (gwelet « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Ha c’hoant hoc’h eus da ginnig ar pennadoù penn-da-benn, pe embann un diverrañ anezho, ennañ un nebeud kantadoù a arouezennoù ?',
	'info_table_prefix' => 'Ma staliit meur a lec’hienn war ar memes diaz titouroù e c’hellit kemmañ ar rakgerioù zo e penn-kentañ anv an diazoù titouroù; ret eo deoc’h skrivañ gant lizherennoù bihan hep tired warno (ñ, ù, é, à, ...) hag hep esaouenn.',
	'info_taille_maximale_images' => 'Emañ SPIP o vont da arnodiñ ment vrasañ posupl ar skeudennoù a c’hell bezañ meret gantañ (e milionoù a bikseloù).<br />Ne vo ket bihanaet ar skeudennoù brasoc’h.',
	'info_taille_maximale_vignette' => 'Ment vrasañ ar skeudennoùigoù krouet gant ar reizhiad :',
	'info_terminer_installation' => 'Bremañ e c’hellit echuiñ gant an argerzh staliañ standard.',
	'info_texte' => 'Testenn',
	'info_texte_explicatif' => 'Testenn displegañ',
	'info_texte_long' => '(Dre ma’z eo hir an destenn eo bet rannet e meur a lodenn, a vo adpeget asambles goude ma vo bet aprouet an destenn)',
	'info_texte_message' => 'Testenn ho kemennadenn :',
	'info_texte_message_02' => 'Testenn ar gemennadenn',
	'info_titre' => 'Titl :',
	'info_total' => 'hollad :',
	'info_tous_articles_en_redaction' => 'An holl bennadoù emeur o skridaozañ',
	'info_tous_articles_presents' => 'An holl pennadoù bet embannet er rubrikenn-mañ',
	'info_tous_articles_refuses' => 'An holl bennadoù distaolet',
	'info_tous_les' => 'an holl :',
	'info_tout_site' => 'Al lec’hienn a-bezh',
	'info_tout_site2' => 'N’eo ket bet troet ar pennad er yezh-mañ.',
	'info_tout_site3' => 'Troet eo bet ar pennad, met abaoe eo bet kemmet ar pennad orin. Ret eo nevesaat an droidigezh.',
	'info_tout_site4' => 'Troet eo bet ar pennad er yezh-mañ, ha n’eus ket ezhomm da nevesaat an droidigezh.',
	'info_tout_site5' => 'Pennad orin.',
	'info_tout_site6' => '<b>Diwallit :</b>Ne vez diskouezet nemet ar pennadoù orin.
Stag eo an troidigezhioù outo,
diskouezet en ul liv disheñvel, diouzh o stad :',
	'info_traductions' => 'Troidigezhioù',
	'info_travail_colaboratif' => 'Labour a-stroll war ar pennadoù',
	'info_un_article' => 'ur pennad,',
	'info_un_site' => 'ul load',
	'info_une_rubrique' => 'ur rubrikenn,',
	'info_une_rubrique_02' => '1 rubrikenn',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL ar proksi',
	'info_url_proxy_pas_conforme' => 'Direizh eo an URL proxy',
	'info_url_site_pas_conforme' => 'n’eo ket reizh URL al lec’hien.',
	'info_url_test_proxy' => 'URL prouata',
	'info_urlref' => 'Liamm gourskrid :',
	'info_utilisation_spip' => 'Bremañ e c’hellit kregiñ da implijout ar reizhiad embann ameilet...',
	'info_visites_par_mois' => 'Diskouez dre viz :',
	'info_visiteur_1' => 'Gweladenner',
	'info_visiteur_2' => 'Mont d’al lec’hienn foran',
	'info_visiteurs' => 'Gweladennerion',
	'info_visiteurs_02' => 'Gweladenner al lec’hienn foran',
	'info_webmestre_forces' => 'termenet eo ar vistri-gwiad bremañ e <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Chomlec’h an diaz titouroù roet gant an herberc’hier',
	'install_connect_ok' => 'Disklêriet eo bet ar bon nevez dindan anv an dafariad @connect@.',
	'install_echec_annonce' => 'Moarvat e c’hwito ar staliadur pe e kaso d’ul lec’hienn na’z aio ket en-dro...',
	'install_extension_mbstring' => 'Ne’z a ket SPIP en-dro gant :',
	'install_extension_php_obligatoire' => 'Ezhomm en deus SPIP eus an astenn php :',
	'install_login_base_hebergeur' => 'Kod kevreañ roet gant an herberc’hier',
	'install_nom_base_hebergeur' => 'Anv an diaz roet gant an herberc’hier :',
	'install_pas_table' => 'Taolenn ebet en diaz evit poent',
	'install_pass_base_hebergeur' => 'Ger-tremen kevreañ roet gant an herberc’hier',
	'install_php_version' => 'n’eo ket trawalc’h stumm @version@ PHP (@minimum@ d’an nebeutañ)',
	'install_select_langue' => 'Diuzit ur yezh, ha klikit war « War-lerc’h » evit kregiñ gant ar staliañ.',
	'install_select_type_db' => 'Merkit ar seurt diaz titouroù :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servijer diaz titouroù lakaet gant an herberc’hier',
	'install_table_prefix_hebergeur' => 'Rakger an diaz roet gant an herberc’hier :',
	'install_tables_base' => 'Taolennoù er reizhiad',
	'install_types_db_connus' => 'Gallout a ra SPIP ober gant <b>MySQL</b> (an hini implijetañ), <b>PostgreSQL</b> ha <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Diwallit : meur a adveziant ne’z eont en-dro nemet gant MySQL',
	'instituer_erreur_statut_a_change' => 'Daskemmet eo bet ar staelad endeo',
	'instituer_erreur_statut_non_autorise' => 'Ne c’hallit ket dibab ar staelad-se',
	'intem_redacteur' => 'skridaozer',
	'intitule_licence' => 'Aotre',
	'item_accepter_inscriptions' => 'Degemer an enskrivadurioù',
	'item_activer_messages_avertissement' => 'Gweredekaat ar c’hemennoù diwall',
	'item_administrateur_2' => 'merour', # MODIF
	'item_afficher_calendrier' => 'Diskouez en deiziataer',
	'item_autoriser_syndication_integrale' => 'Skignañ an holl bennadoù er restroù sindikadañ',
	'item_choix_administrateurs' => 'ar verourion', # MODIF
	'item_choix_generation_miniature' => 'Krouiñ arlunioù ar skeudennoù en un doare emgefre.',
	'item_choix_non_generation_miniature' => 'Chom hep krouiñ arlunioù diwar skeudennoù.',
	'item_choix_redacteurs' => 'ar skridaozerion',
	'item_choix_visiteurs' => 'gweladennerien al lec’hienn foran',
	'item_creer_fichiers_authent' => 'Krouiñ ar restroù .htpasswd',
	'item_login' => 'Kod kevreañ',
	'item_messagerie_agenda' => 'Gweredekaat ar postelerezh hag an deiziataer',
	'item_mots_cles_association_articles' => 'ouzh ar pennadoù',
	'item_mots_cles_association_rubriques' => 'ouzh ar rubrikennoù',
	'item_mots_cles_association_sites' => 'ouzh al lec’hiennoù rollet pe sindikadet.',
	'item_non' => 'Ket',
	'item_non_accepter_inscriptions' => 'Chom hep degemer an enskrivadurioù',
	'item_non_activer_messages_avertissement' => 'Kemenn diwall ebet',
	'item_non_afficher_calendrier' => 'Chom hep diskouez en deiziataer',
	'item_non_autoriser_syndication_integrale' => 'Embann un diverrañ hepken',
	'item_non_creer_fichiers_authent' => 'Arabat krouiñ ar restroù-se',
	'item_non_messagerie_agenda' => 'Diweredekaat ar postelerezh hag an deiziataer',
	'item_non_publier_articles' => 'Na embann ar pennadoù a-raok an deiziad embann lakaet.',
	'item_nouvel_auteur' => 'Skridaozer nevez',
	'item_nouvelle_rubrique' => 'Rubrikenn nevez',
	'item_oui' => 'Ya',
	'item_publier_articles' => 'Embann ar pennadoù, ne vern an deiziad embann lakaet dezho.',
	'item_reponse_article' => 'Respont d’ar pennad',
	'item_visiteur' => 'gweladenner',

	// J
	'jour_non_connu_nc' => 'dianav',

	// L
	'label_bando_outils' => 'Barrenn ostilhoù',
	'label_bando_outils_afficher' => 'Diskouez an ostilhoù',
	'label_bando_outils_masquer' => 'Kuzhat an ostilhoù',
	'label_choix_langue' => 'Dibabit ho yezh',
	'label_nom_fichier_connect' => 'Lakait anv an dafariad-mañ',
	'label_slogan_site' => 'Lugan al load internet',
	'label_taille_ecran' => 'Ledander ar skramm',
	'label_texte_et_icones_navigation' => 'Lañser gwedeiñ',
	'label_texte_et_icones_page' => 'Diskouez er bajenn',
	'ldap_correspondance' => 'hêrezh ar vaezienn @champ@',
	'ldap_correspondance_1' => 'Hêrezh ar maeziennoù LDAP',
	'ldap_correspondance_2' => 'Merkañ anv ar vaezienn LDAP evit pep hini eus ar maeziennoù SPIP da-heul. Lezel goullo kuit na vefe leuniet pa dispartiañ dre skejoù evit esaeañ meur a vaezienn LDAP.',
	'lien_ajouter_auteur' => 'Ouzhpennañ ar skridaozer-mañ',
	'lien_ajouter_une_rubrique' => 'Ouzhpennañ ar rubrikenn-mañ',
	'lien_email' => 'postel',
	'lien_nom_site' => 'ANV AL LEC’HIENN :',
	'lien_rapide_contenu' => 'Mont d’an endalc’had',
	'lien_rapide_navigation' => 'Mont da verdeiñ',
	'lien_rapide_recherche' => 'Mont d’an enklask',
	'lien_retirer_auteur' => 'Lemel ar skridaozer',
	'lien_retirer_rubrique' => 'Tennañ kuit ar rubrikenn',
	'lien_retirer_tous_auteurs' => 'Tennañ kuit an holl aozerion',
	'lien_retirer_toutes_rubriques' => 'Tennañ kuit holl ar rubrikennoù',
	'lien_site' => 'lec’hienn',
	'lien_tout_decocher' => 'Diaskañ an holl',
	'lien_tout_deplier' => 'Dispakañ pep tra',
	'lien_tout_replier' => 'Adpakañ pep tra',
	'lien_tout_supprimer' => 'Diverkañ pep tra',
	'lien_trier_nom' => 'Renkañ diouzh an anv',
	'lien_trier_nombre_articles' => 'Renkañ diouzh an niver a bennadoù',
	'lien_trier_statut' => 'Renkañ diouzh ar statud',
	'lien_voir_en_ligne' => 'GWELET ENLINENN :',
	'logo_article' => 'LOGO AR PENNAD',
	'logo_auteur' => 'LOGO AR SKRIDAOZER',
	'logo_rubrique' => 'LOGO AR RUBRIKENN',
	'logo_site' => 'LOGO AL LOAD INTERNET-MAÑ',
	'logo_standard_rubrique' => 'LOGO BOAS AR RUBRIKENNOÙ',
	'logo_survol' => 'LOGO RIKLAÑ AL LOGODENN',

	// M
	'menu_aide_installation_choix_base' => 'dibab ho tiaz',
	'module_fichier_langue' => 'Restr yezh',
	'module_raccourci' => 'Berradenn',
	'module_texte_affiche' => 'Testenn diskouezet',
	'module_texte_explicatif' => 'Gallout a rit ouzhpennañ ar berradennoù da-heul e frammoù al lec’hienn foran. En un doare emgefreek e vint troet er yezhoù ma’z eus ur restr yezh.',
	'module_texte_traduction' => 'Gallout a reer kaout ar restr yezh « @module@ » e :',
	'mois_non_connu' => 'dianav',

	// N
	'nouvelle_version_spip' => 'Prest eo an hizivaat @version@ SPIP ',
	'nouvelle_version_spip_majeure' => 'Prest eo ur stumm SPIP @version@',

	// O
	'onglet_contenu' => 'Endalc’had',
	'onglet_declarer_une_autre_base' => 'Disklêriañ un diaz all',
	'onglet_discuter' => 'Flapiñ',
	'onglet_interactivite' => 'Etreobererezh',
	'onglet_proprietes' => 'Perzhioù',
	'onglet_repartition_actuelle' => 'betek-henn',
	'onglet_sous_rubriques' => 'Isrummadoù',

	// P
	'page_pas_proxy' => 'Arabat d’ar bajenn-mañ tremen dre ar proksi',
	'pas_de_proxy_pour' => 'Ma vez ezhomm merkit ar mekanikoù pe domanioù na zle ket ar proksi-mañ mont en-dro evito (da skouer : @exemple@)',
	'phpinfo' => 'Kefluniadur PHP',
	'plugin_charge_paquet' => 'Kargañ ar pakad @name@',
	'plugin_charger' => 'Pellgargañ',
	'plugin_erreur_charger' => 'fazi : dibosupl eo kargañ @zip@',
	'plugin_erreur_droit1' => 'N’haller ket skrivañ war ar c’havlec’h <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Gwiriit an aotreoù war ar c’havlec’h-mañ (ha kempennit anezho diouzh ret), pe stailhit ar restroù dre FTP.',
	'plugin_erreur_zip' => 'fazi pclzip : fazi @status@',
	'plugin_etat_developpement' => 'o tiorren',
	'plugin_etat_experimental' => 'arnodel',
	'plugin_etat_stable' => 'stabil',
	'plugin_etat_test' => 'o vezañ amprouet',
	'plugin_impossible_activer' => 'Dibosupl eo gweredekaat an adveziant @plugin@',
	'plugin_info_automatique1' => 'Mar fell deoc’h aotren staliadur emgefre an adveziantoù, setu penaos :',
	'plugin_info_automatique1_lib' => 'Mard oc’h a-du da zesezañ emgefreek al levraoueg-mañ, teurvezit:',
	'plugin_info_automatique2' => 'krouit ur c’havlec’h <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Gwiriit eo aotreet-mat ar servijer da skrivañ er c’havlec’h-se.',
	'plugin_info_automatique_creer' => 'da grouiñ e gwrizienn al lec’hienn.',
	'plugin_info_automatique_exemples' => 'da skouer :',
	'plugin_info_automatique_ftp' => 'Gallout a rit staliañ adveziantoù dre FTP er c’havlec’h <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Adveziantoù zo a c’houlenn gellout pellgargañ restroù er c’havlec’h <code>lib/</code>. Da vezañ krouet, diouzh an dro, e gwrizienn al lec’hienn.',
	'plugin_info_automatique_liste' => 'Ho rolloù adveziantoù :',
	'plugin_info_automatique_liste_officielle' => 'An adveziantoù ofisiel',
	'plugin_info_automatique_liste_update' => 'Hizivaat ar rolloù',
	'plugin_info_automatique_ou' => 'pe...',
	'plugin_info_automatique_select' => 'Diuzit un adveziant amañ a-is : pellgarget e vo gant SPIP ha staliet er c’havlec’h <code>@rep@</code> ; ma’z eus eus an adveziant-mañ c’hoazh e vo hizivaet.',
	'plugin_info_credit' => 'Diwar',
	'plugin_info_erreur_xml' => 'Direizh eo disklêriadur an askouez plugin-mañ',
	'plugin_info_install_ok' => 'Desezañ deuet da vat !',
	'plugin_info_necessite' => 'Ret :',
	'plugin_info_non_compatible_spip' => 'Ne glot ket ar plugin-mañ gant an handelv SPIP-mañ',
	'plugin_info_plugins_dist_1' => 'Karget ha gweredek eo an askouezioù-mañ er c’havlec’h @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Diweredekaus ez int',
	'plugin_info_telecharger' => 'da bellgargañ adal @url@ ha da staliañ e @rep@',
	'plugin_info_upgrade_ok' => 'Hizivaat bet kaset da benn',
	'plugin_librairies_installees' => 'Levraouegoù bet staliet',
	'plugin_necessite_extension_php' => 'Ezhomm en deus astenn PHP @plugin@ en version @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Ezhomm en deus astenn PHP @plugin@',
	'plugin_necessite_lib' => 'Ezhomm en deus an adveziant-mañ eus al levraoueg @lib@',
	'plugin_necessite_php' => 'Ezhomm en deus @plugin@ en version @version@.',
	'plugin_necessite_plugin' => 'Ezhomm en deus eus an adveziant @plugin@ e stumm @version@.',
	'plugin_necessite_plugin_sans_version' => 'Askouez @plugin@ ret',
	'plugin_necessite_spip' => 'Ezhomm zo eus stumm @version@ SPIP da nebeutañ.',
	'plugin_source' => 'orin: ',
	'plugin_titre_automatique' => 'Staliadur emgefre',
	'plugin_titre_automatique_ajouter' => 'Ouzhpennañ adveziantoù',
	'plugin_titre_installation' => 'Desezañ an askouez @plugin@',
	'plugin_titre_modifier' => 'Va askouezioù plugin',
	'plugin_utilise_extension_php' => 'An astenn PHP @plugin@ rank bezañ e stumm @version@.',
	'plugin_utilise_php' => ' @plugin@ a rank bezañ @version@.',
	'plugin_utilise_plugin' => 'Ar plugin @plugin@ rank bezañ e doare @version@.',
	'plugin_zip_active' => 'Kendalc’hit evit e weredekaat',
	'plugin_zip_adresse' => 'merkit amañ a-is chomlec’h restr zip un adveziant da bellgargañ, pe hini ul rollad adveziantoù.',
	'plugin_zip_adresse_champ' => 'Chomlec’h an adveziant pe hini ar roll ',
	'plugin_zip_content' => 'Ennañ emañ ar restroù (@taille@),<br />prest da vezañ staliet er c’havlec’h <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Diwasket ha staliet eo bet ar restr @zip@ .',
	'plugin_zip_installe_rep_finie' => 'Diwasket eo bet ar restr @zip@ ha staliet er c’havlec’h @rep@',
	'plugin_zip_installer' => 'Bremañ e c’hellit staliañ anezhañ.',
	'plugin_zip_telecharge' => 'Pellgarget eo bet ar restr @zip@',
	'plugins_actif_aucun' => 'Askouez plugin gweredek ebet',
	'plugins_actif_un' => 'Un askouez plugin gweredek',
	'plugins_actifs' => '@count@ adveziant gweredekaet.',
	'plugins_actifs_liste' => 'Gweredek',
	'plugins_compte' => '@count@ adveziant',
	'plugins_disponible_un' => 'Un askouez plugin prest',
	'plugins_disponibles' => '@count@ adveziant hegerz.',
	'plugins_erreur' => 'Fazi en adveziantoù : @plugins@',
	'plugins_liste' => 'Roll an adveziantoù',
	'plugins_liste_dist' => 'Askouezioù plugin prennet',
	'plugins_recents' => 'Askouezioù Plugin nevez',
	'plugins_tous_liste' => 'Holl',
	'plugins_vue_hierarchie' => 'Urzhaz',
	'plugins_vue_liste' => 'Roll',
	'protocole_ldap' => 'Stumm ar protokol :',

	// Q
	'queue_executer_maintenant' => 'Seveniñ bremañ',
	'queue_info_purger' => 'Bez e c’hallit lemel an holl labourioù o c’hortoz, ha nevesaat roll al labourioù mareadek',
	'queue_nb_jobs_in_queue' => '@nb@ labourioù o c’hortoz',
	'queue_next_job_in_nb_sec' => 'Labour-all a-benn @nb@ eilenn',
	'queue_no_job_in_queue' => 'Labour ebet o chom a-ispilh',
	'queue_one_job_in_queue' => '1 labour o chom a-ispilh',
	'queue_priorite_tache' => 'prioriezh',
	'queue_purger_queue' => 'Nevesaat roll al labourioù',
	'queue_titre' => 'Roll al labourioù en-adreñv',

	// R
	'repertoire_plugins' => 'Kavlec’h :',
	'required' => '[Rekis]',

	// S
	'sans_heure' => 'hep eur',
	'statut_admin_restreint' => 'merour strishaet',
	'statut_webmestre' => 'mestr-gwiad',

	// T
	'tache_cron_asap' => 'Lodenn labour CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Lodenn labour CRON @function@ (bep @nb@ eilenn)',
	'taille_cache_image' => '@taille@ eo hollad ar skeudennoù jedet gant ent emgefre gant SPIP (skeudennigoù an teulioù, an titloù kinniget dindan ur stumm grafek, ar fonksionoù jedoniezh er stumm TeX...) hag a zo er c’havlec’h @dir@.',
	'taille_cache_moins_de' => 'Ment ar c’huzh@octets@.',
	'taille_cache_octets' => '@octets@ eo ment ar grubuilh evit ar mare.',
	'taille_cache_vide' => 'Goullo eo ar grubuilh',
	'taille_repertoire_cache' => 'Ment kavlec’h ar grubuilh',
	'text_article_propose_publication' => 'Pennad kinniget evit an embann.',
	'texte_acces_ldap_anonyme_1' => 'Servijerioù LDAP zo ne aotreont ket ar monedoù dizanv. En degouezh-se e vo ret deoc’h merkañ un anv moned a-raok gallout klask titouroù er rollad. Peurliesañ e c’hallot lezel goullo ar maeziennoù-se koulskoude.',
	'texte_admin_effacer_01' => 'Diverkañ a raio an urzhad-se <i>PEP TRA</i> en ho tiaz titouroù,
da lavaret eo <i>holl</i> aotreoù ar verourien hag ar skridaozerien. Goude bezañ bet graet se e rankot
adstaliañ SPIP hag adkrouiñ un diaz titouroù nevez hag ur moned merour kentañ nevez.', # MODIF
	'texte_adresse_annuaire_1' => '(M’eo staliet ar roll tud war an hevelep mekanik hag al lec’hienn-mañ, e tle bezañ «localhost».)',
	'texte_ajout_auteur' => 'Ouzhpennet eo bet ar skridaozer-mañ d’ar pennad :',
	'texte_annuaire_ldap_1' => 'M’hoc’h eus tro d’ober gant ur roll tud (LDAP) e c’hellit e implijout evit enporzhiañ implijerien war SPIP ent emgefre.', # MODIF
	'texte_article_statut' => 'Ar pennad-mañ zo :',
	'texte_article_virtuel' => 'Pennad galloudel',
	'texte_article_virtuel_reference' => '<b>pennad galloudel :</b> pennad menegeret en ho lec’hienn SPIP, met adkaset war-du un URL all. Evit paouez gant an adkas, diverkañ an URL a-us.',
	'texte_aucun_resultat_auteur' => 'Disoc’h ebet evit "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Gallout a ra al lec’hienn-mañ diskouez deoc’h roll ar skridaozerien kevreet a-hed an amzer, ar pezh a aotren ac’hanoc’h da eskemm ganto war ar prim. Gallout a rit dibab chom hep dont war wel war ar roll-mañ (« diwelus » oc’h neuze evit an implijerien all).', # MODIF
	'texte_auteurs' => 'AR SKRIDAOZERIEN',
	'texte_choix_base_1' => 'Dibabit ho tiaz :',
	'texte_choix_base_2' => 'Er servijer SQL ez eus meur a ziaz titouroù.',
	'texte_choix_base_3' => '<b>Diuzit</b> amañ dindan an hini zo bet lakaet deoc’h gant an herberc’hier :',
	'texte_choix_table_prefix' => 'Rakger an taolennoù :',
	'texte_compte_element' => '@count@ elfenn',
	'texte_compte_elements' => '@count@ elfenn',
	'texte_conflit_edition_correction' => 'Gwiriit amañ dindan an diforc’hioù etre daou stumm an destenn. Gallout a rit ivez eilañ ho kemmoù, hag adkregiñ.',
	'texte_connexion_mysql' => 'Sellit ouzh an titouroù roet gant an herberc’hier : Enno e tlefec’h kavout ar servijer diazoù titouroù a vez kinniget gantañ hag ar c’hodoù kevreañ personel.',
	'texte_contenu_article' => '(Kinnig ar pennad berr-ha-berr.)',
	'texte_contenu_articles' => 'Hevez ar vaketenn dibabet evit sevel ho lec’hienn e c’hellit divizout
  ne vo ket implijet elfennoù zo er pennadoù.
  Implijit al listenn amañ dindan evit merkañ pere eo an elfennoù a c’heller ober ganto.',
	'texte_crash_base' => 'Ma’z eo sac’het ho tiaz titouroù e c’hellit klask ratreañ en un doare emgefreek.',
	'texte_creer_rubrique' => 'A-raok gallout skrivañ pennadoù<br /> e rankit krouiñ ur rubrikenn.',
	'texte_date_creation_article' => 'DEIZIAD KROUIÑ AR PENNAD :',
	'texte_date_creation_objet' => 'Deiziad krouiñ :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'DEIZIAD EMBANN KENT :',
	'texte_date_publication_anterieure_nonaffichee' => 'Na ziskouez an deiziad embann kent.',
	'texte_date_publication_article' => 'DEIZIAD EMBANN ENLINENN :',
	'texte_date_publication_objet' => 'Deiziad embann enlinenn :',
	'texte_definir_comme_traduction_rubrique' => 'Ur droidigezh eo ar rubrikenn-mañ deus ar rubrikenn niverenn :',
	'texte_descriptif_rapide' => 'Berr-ha-berr',
	'texte_effacer_base' => 'Diverkañ diaz titouroù SPIP',
	'texte_effacer_statistiques' => 'Diverkañ ar stadegoù',
	'texte_en_cours_validation' => 'Kinniget eo ar pennadoù ha berrskridoù amañ dindan d’an embann.',
	'texte_enrichir_mise_a_jour' => 'Gallout a rit bravaat pajennaozañ ho testenn en ur implijout « berradennoù tipografek ».',
	'texte_fichier_authent' => '<b>Ha rankout a ra SPIP krouiñ ar restroù dibar <tt>.htpasswd</tt>
  ha <tt>.htpasswd-admin</tt> er c’havlec’h @dossier@ ?</b><p>
  Gant ar restroù-se e c’hallit herzel ouzh ar re n’int ket skridaozer pe merour da vont war bajenoù all zo
  (programm stadegoù diavaez, da skouer).</p><p>
  Ma n’hoc’h eus ket ezhomm d’hen ober e c’hellit lezel an traoù evel m’emaint lakaet dre-ziouer
  (ne vo ket krouet ar restroù).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Bremañ e vo krouet gant ar reizhiad ur moned personel d’al lec’hienn evidoc’h.',
	'texte_informations_personnelles_2' => '(Notenn : m’emaoc’h oc’h adstaliañ SPIP hag ez a c’hoazh ho moned kozh en-dro e c’hallit ',
	'texte_introductif_article' => '(Testenn digeriñ ar pennad)',
	'texte_jeu_caractere' => 'Gant al lizherenneg hollvedel (<tt>utf-8</tt>) oc’h aliet d’ober : aotren a ra diskwel testennoù en holl yezhoù, ha ne sav kudenn kenglotañ ebet ken gant ar merdeerioù a-vremañ.',
	'texte_jeu_caractere_3' => 'Gant ar strobad arouezennoù-mañ e ra ho lec’hienn :',
	'texte_jeu_caractere_4' => 'Ma ne glot ket gant gwirvoud ho roadennoù (da skouer, m’emaoc’h o paouez assevel un diaz titouroù), pe ma <em>loc’hit gant al lec’hienn-mañ</em> hag hoc’h eus c’hoant d’ober gant ur strobad arouezennoù all, resisait se amañ dindan :',
	'texte_login_ldap_1' => '(Na skrivit netra evit ur moned dizanv, pe skrivit an hent klok, da skouer « <tt>uid=anv, ou=users, dc=ma-zomani, dc=com</tt> ».)',
	'texte_login_precaution' => 'Diwallit ! Setu ar c’hod kevreañ a dalvez deoc’h da gevreañ evit ar mare.
 Taolit evezh gant ar furmskrid-mañ...',
	'texte_messagerie_agenda' => 'Gant ur postelerezh e c’hell ar skridaozerien eskemm an eil gant egile dre lodenn brevez al lec’hienn. Un deiziataer zo stag outañ.', # MODIF
	'texte_mise_a_niveau_base_1' => 'O paouez hizivaat restroù SPIP emaoc’h. Bremañ eo dav ober kemend-all evit an diaz titouroù.',
	'texte_modifier_article' => 'Kemmañ ar pennad :',
	'texte_multilinguisme' => 'Mar fell deoc’h merañ pennadoù e meur a yezh, dre un doare merdeiñ kemplezh, e c’hallit ouzhpennañ ul lañser dibab yezhoù war ar pennadoù ha/pe war ar rubrikennoù, hervez ar mod m’eo aozet ho load internet.',
	'texte_multilinguisme_trad' => 'Gallout a rit gweredekaat ur reizhiad merañ liammoù etre troidigezhioù disheñvel ar pennadoù ivez.',
	'texte_non_compresse' => '<i>ket gwasket</i> (ne vez ket skoret an arc’hwel-se gant ho servijer)',
	'texte_nouvelle_version_spip_1' => 'Ur stumm nevez eus SPIP zo bet staliet ganeoc’h.',
	'texte_nouvelle_version_spip_2' => 'Evit peurstaliañ anezhañ ez eus ezhomm un hizivadenn glokoc’h eget boaz. Ma’z oc’h webmestr al lec’hienn, diverkit ar restr @connect@ hag adkrogit gant ar staliadur a-benn hizivaat an arventennoù kevreañ ouzh an diaz titouroù.<p> (NM. M’hoc’h eus ankouaet ho titouroù kevreañ , taolit ur sell ouzh ar restr @connect@ a-raok he diverkañ...)</p>',
	'texte_operation_echec' => 'Distroit d’ar bajenn kent, diuzit un diaz all, pe krouit unan nevez. Gwiriit an titouroù bet roet deoc’h gant an herberc’hier.',
	'texte_plus_trois_car' => 'ouzhpenn 3 arouezenn',
	'texte_plusieurs_articles' => 'Meur a skridaozer bet kavet evit "@cherche_auteur@":',
	'texte_port_annuaire' => '(Peurliesañ e tegouezh an talvoud roet dre ziouer.)',
	'texte_presente_plugin' => 'War ar bajenn-mañ emañ rollet an adveziantoù hegerz evit al lec’hienn-mañ. Gallout a rit gweredekaat an adveziantoù a fell deoc’h, en ur askañ al log a zere',
	'texte_proposer_publication' => 'Ur wech echu ho pennad <br /> e c’hellit kinnig ma vo embannet.',
	'texte_proxy' => 'E degouezhioù zo (enrouedad, rouedadoù gwarezet,...), n’hallo al lec’hiennoù pell (teuliad skoazell SPIP, lec’hiennoù sindikadet, ...) bezañ tizhet nemet dre ur <i>proksi HTTP</i>. Diouzh ma vez, skrivit amañ dindan ar chomlec’h anezhañ, er stumm @proxy_en_cours@. Peurliesañ ne vo skrivet netra amañ.',
	'texte_publication_articles_post_dates' => 'Peseurt emzalc’h a zle SPIP kaout gant ar pennadoù zo bet lakaet dezho un deiziad embann en amzer da zont ?',
	'texte_rappel_selection_champs' => '[N’ankouait ket diuzañ mat ar vaezienn-mañ.]',
	'texte_recalcul_page' => 'Mar fell deoc’h adjediñ ur bajenn hepken, tremenit kentoc’h dre al lodenn foran hag implijit an nozelenn « adjediñ ».',
	'texte_recuperer_base' => 'Ratreañ an diaz titouroù',
	'texte_reference_mais_redirige' => 'pennad menegeret en ho lec’hienn SPIP, met adkaset davet un URL all.',
	'texte_requetes_echouent' => '<b>Pa chom sac’het ingal pe hep abeg rekedoù SQL,
  e c’hell bezañ abalamour d’an diaz titouroù</b><p>
  Gant SQL e c’hell an taolennnoù en em gempenn o-unan p’int bet nodet dre zegouezh.
  Amañ e c’hallit klask adgempenn anezho. Ma c’hwit, mirit un eilenn eus an doare diskwel, e ken kaz ma vefe titouroù talvoudus ennañ.</p><p>
  Kit e darempred gant an herberc’hier ma c’hoarvez ar gudenn adarre.</p>',
	'texte_selection_langue_principale' => 'Amañ dindan e c’hellit diuzañ « yezh pennañ » al lec’hienn. Ne dalvez ket e viot rediet da skrivañ ho pennadoù er yezh-se, met servijout a ra da resisaat :
 <ul><li> ar furmad dre ziouer da ziskouez an deiziadoù war al lec’hienn foran ;</li>
 <li> peseurt lusker skrivañ a rank bezañ implijet gant SPIP evit diskouez an testennoù ;</li>
 <li> ar yezh implijet e furmskridoù al lodenn foran ;</li>
 <li> ar yezh implijet dre ziouer el lodenn brevez.</li></ul>',
	'texte_sous_titre' => 'Istitl',
	'texte_statistiques_visites' => '(barrennoù teñval :  Sul / krommenn deñval : emdroadur ar geidenn)',
	'texte_statut_attente_validation' => 'o c’hortoz bezañ asantet',
	'texte_statut_publies' => 'embannet enlinenn',
	'texte_statut_refuses' => 'nac’het',
	'texte_suppression_fichiers' => 'Implijit an urzhiad-se evit diverkañ an holl restroù krubuilhet e SPIP. An dra-se a c’hell servijout evit ma vo adjedet ho holl pajennoù, dre heg, m’hoc’h eus graet kemmoù bras e neuz pe e framm al lec’hienn.',
	'texte_sur_titre' => 'Ustitl',
	'texte_table_ok' => ': kudenn ebet gant an daolenn-mañ.',
	'texte_tentative_recuperation' => 'Taol-esa evit ratreañ',
	'texte_tenter_reparation' => 'Klask ratreañ an diaz roadennoù',
	'texte_test_proxy' => 'Evit amprouiñ ar proksi-mañ, skrivit amañ dindan chomlec’h al lec’hienn a fell deoc’h arnodiñ.',
	'texte_titre_02' => 'Titl :',
	'texte_titre_obligatoire' => '<b>Titl</b> [Rekis]',
	'texte_travail_article' => '@nom_auteur_modif@ en deus labouret war ar pennad-mañ @date_diff@ munutenn zo',
	'texte_travail_collaboratif' => 'Ma c’hoarvez alies e labourfe meur a zen war an hevelep pennad 
  e c’hell ar reizhiad diskouez ar pennadoù bet « digoret » nevez zo
  a-benn herzel ma vo graet meur a gemm war un dro.
  Diweredekaet eo an dibarzh-mañ dre ziouer kuit da gaout kemennoù diwall a-hed an amzer.', # MODIF
	'texte_vide' => 'goullo',
	'texte_vider_cache' => 'Goullonderiñ ar grubuilh',
	'titre_admin_tech' => 'Trezalc’h teknikel',
	'titre_ajouter_un_auteur' => 'Ouzhpennañ un aozer',
	'titre_ajouter_un_mot' => 'Ouzhpennañ ur ger-alc’hwez',
	'titre_cadre_afficher_article' => 'Diskouez ar pennadoù',
	'titre_cadre_afficher_traductions' => 'Diskouez stad an troidigezhioù evit ar yezhoù-mañ :',
	'titre_cadre_ajouter_auteur' => 'OUZHPENNAÑ UR SKRIDAOZER :',
	'titre_cadre_interieur_rubrique' => 'Er rubrikenn',
	'titre_cadre_numero_auteur' => 'SKRIDAOZER NIVERENN',
	'titre_cadre_numero_objet' => '@objet@ NIVERENN :',
	'titre_cadre_signature_obligatoire' => '<b>Sinadur</b> [Rekis]<br />',
	'titre_config_contenu_notifications' => 'Kemennoù nevezinti',
	'titre_config_contenu_prive' => 'El lodenn brevez',
	'titre_config_contenu_public' => 'War al lec’hienn foran',
	'titre_config_fonctions' => 'Kefluniadur al lec’hienn',
	'titre_config_langage' => 'Kefluniañ ar yezh',
	'titre_configuration' => 'Kefluniañ al lec’hienn',
	'titre_configurer_preferences' => 'Kefluniañ ho tibaboù',
	'titre_configurer_preferences_menus' => 'Kefluniañ an dibarzhoù er pennroll',
	'titre_conflit_edition' => 'Bec’h e-ser embann',
	'titre_connexion_ldap' => 'Dibarzhioù : <b>Ho kevreadenn LDAP</b>',
	'titre_groupe_mots' => 'STROLLAD GERIOÙ :',
	'titre_identite_site' => 'Merk hennadiñ al load internet',
	'titre_langue_article' => 'Yezh ar pennad-skrid',
	'titre_langue_rubrique' => 'YEZH AR RUBRIKENN',
	'titre_langue_trad_article' => 'YEZH HA TROIDIGEZHIOÙ AR PENNAD',
	'titre_les_articles' => 'AR PENNADOÙ',
	'titre_messagerie_agenda' => 'Postelerezh ha deiziataer',
	'titre_naviguer_dans_le_site' => 'Merdeiñ el lec’hienn...',
	'titre_nouvelle_rubrique' => 'Rubrikenn nevez',
	'titre_numero_rubrique' => 'RUBRIKENN NIVERENN :',
	'titre_page_articles_edit' => 'Kemmañ : @titre@',
	'titre_page_articles_page' => 'Ar pennadoù',
	'titre_page_articles_tous' => 'Al lec’hienn a-bezh',
	'titre_page_calendrier' => 'Deiziataer @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Kefluniañ al lec’hienn',
	'titre_page_delete_all' => 'diverket e vo pep tra, ne vo ket tu da zont war-gil',
	'titre_page_recherche' => 'Disoc’hoù an enklask @recherche@',
	'titre_page_statistiques_referers' => 'Stadegoù (liammoù davet al lec’hienn-mañ)',
	'titre_page_upgrade' => 'Hizivaat SPIP',
	'titre_preference_menus_favoris' => 'Pennrolloù',
	'titre_publication_articles_post_dates' => 'Embann ar pennadoù deiziataet a-c’houde',
	'titre_reparation' => 'Kempenn',
	'titre_suivi_petition' => 'Heuliañ ar sinadegoù',
	'tls_ldap' => 'Surentez Treuzdougen a-Wiskadoù :',
	'trad_article_traduction' => 'Holl stummoù ar pennad-mañ :',
	'trad_delier' => 'Paouez da liammañ ar pennad-mañ ouzh an troidigezhioù anezhañ',
	'trad_lier' => 'Un droidigezh eo ar pennad-mañ. Setu niverenn ar pennad orin :',
	'trad_new' => 'Skrivañ un droidigezh nevez evit ar pennad-mañ',

	// U
	'utf8_convert_erreur_orig' => 'Fazi : n’eo ket skoret ar strobad arouezennoù @charset@',

	// V
	'version' => 'Stumm :',
];
